==> dvdisaster_0.72.3.orig.tar.bz2: dvdisaster-0.72.3/documentation/ru/privacy.php <==
<?php
# dvdisaster: English homepage translation
# Copyright (C) 2004-2010 Carsten Gnörlich
#
# UTF-8 trigger: äöüß 
#
# Include our PHP sub routines, then call begin_page()
# to start the HTML page, insert the header, 
# navigation and news if appropriate.

require("../include/dvdisaster.php");
begin_page();
?>

<!--- Insert actual page content below --->

<b>Заявление о конфиденциальности для веб-сайтов</b><p>

dvdisaster.com, &nbsp; 
dvdisaster.de, &nbsp;
dvdisaster.net, &nbsp;
dvdisaster.org

<p>

Проект dvdisaster (<a href="imprint.php">представители указаны в выходных данных</a>)
серьезно относится к вашей конфиденциальности. Следующее заявление - странность, 
требуемая немецким законодательством. Оно дает вам представление о том, какого 
типа данные и с какой целью мы собираем:

<p>

<b>Журналы</b> (данные, обрабатываемые нашими интернет-серверами)<p>

Посещения наших интернет-сайтов журналируется. 
Наши сервера собирают следующие данные:

<ul>
<li>тип и версию вашего браузера</li>
<li>используемая операционная система</li>
<li>веб-сайт, с которого вы были направлены на наш интернет-сайт (если это применимо)</li>
<li>имя или IP-адрес компьютера, с которого сделан доступ</li>
<li>время и дата запроса сервера</li>
<li>именя файлов посещенных страниц.</li>
</ul>

Эти данные не используются для идентификации посетителей наших веб-сайтов.
Они не будут рассматриваться в сочетании с другими источниками данных. Эти данные будут 
удалены после статистического анализа.

<p>

<b>Cookies</b><p>

Этот интернет-сайт не использует cookies.

<p>

<b>Ссылки на другие интернет-сайты</b><p>

Наши интернет-страницы содержат ссылки на другие интернет-сайты.
Проект dvdisaster не имеет контроля над их издателями,
а также над тем, следуют ли они нашей политике конфиденциальности.

<p>

<b>Дальнейшее развитие этих интернет-страниц</b><p>

Дальнейшее развитие этих интернет-страниц может потребовать изменения нашей
политики конфиденциальности. Пожалуйста, время от времени просматривайте это заявление 
о конфиденциальности и следите за уведомлениями об изменениях. 

<!--- do not change below --->

<?php
# end_page() adds the footer line and closes the HTML properly.

end_page();
?>

==> dvdisaster_0.72.4.orig.tar.bz2: dvdisaster-0.72.4/documentation/ru/privacy.php <==
<?php
# dvdisaster: English homepage translation
# Copyright (C) 2004-2012 Carsten Gnörlich
#
# UTF-8 trigger: äöüß 
#
# Include our PHP sub routines, then call begin_page()
# to start the HTML page, insert the header, 
# navigation and news if appropriate.

require("../include/dvdisaster.php");
begin_page();
?>

<!-- Insert actual page content below -->

<b>Заявление о конфиденциальности для веб-сайтов</b><p>

dvdisaster.com, &nbsp; 
dvdisaster.de, &nbsp;
dvdisaster.net, &nbsp;
dvdisaster.org

<p>

Проект dvdisaster (<a href="imprint.php">представители указаны в выходных данных</a>)
серьезно относится к вашей конфиденциальности. Следующее заявление - странность, 
требуемая немецким законодательством. Оно дает вам представление о том, какого 
типа данные и с какой целью мы собираем:

<p>

<b>Журналы</b> (данные, обрабатываемые нашими интернет-серверами)<p>

Посещения наших интернет-сайтов журналируется. 
Наши сервера собирают следующие данные:

<ul>
<li>тип и версию вашего браузера</li>
<li>используемая операционная система</li>
<li>веб-сайт, с которого вы были направлены на наш интернет-сайт (если это применимо)</li>
<li>имя или IP-адрес компьютера, с которого сделан доступ</li>
<li>время и дата запроса сервера</li>
<li>именя файлов посещенных страниц.</li>
</ul>

Эти данные не используются для идентификации посетителей наших веб-сайтов.
Они не будут рассматриваться в сочетании с другими источниками данных. Эти данные будут 
удалены после статистического анализа.

<p>

<b>Cookies</b><p>

Этот интернет-сайт не использует cookies.

<p>

<b>Ссылки на другие интернет-сайты</b><p>

Наши интернет-страницы содержат ссылки на другие интернет-сайты.
Проект dvdisaster не имеет контроля над их издателями,
а также над тем, следуют ли они нашей политике конфиденциальности.

<p>

<b>Дальнейшее развитие этих интернет-страниц</b><p>

Дальнейшее развитие этих интернет-страниц может потребовать изменения нашей
политики конфиденциальности. Пожалуйста, время от времени просматривайте это заявление 
о конфиденциальности и следите за уведомлениями об изменениях. 

<!-- do not change below -->

<?php
# end_page() adds the footer line and closes the HTML properly.

end_page();
?>
